**Example 1: 修改应用**

修改应用的相关信息

Input: 

```
tccli lcic ModifyApp --cli-unfold-argument  \
    --SdkAppId 1234657 \
    --Callback xx
```

Output: 
```
{
    "Response": {
        "RequestId": "xx"
    }
}
```

